package org.sonatype.appcontext.internal;

/**
 * Guava, we love you :D But I'd like to keep dependencies to minimum.
 * 
 * @author cstamas
 */
public class Preconditions
{
    /**
     * Ensures that an object reference passed as a parameter to the calling method is not null.
     * 
     * @param reference an object reference
     * @return the non-null reference that was validated
     * @throws NullPointerException if {@code reference} is null
     */
    public static <T> T checkNotNull( T reference )
    {
        return checkNotNull( reference, "Argument cannot be null!" );
    }

    /**
     * Ensures that an object reference passed as a parameter to the calling method is not null.
     * 
     * @param reference an object reference
     * @param errorMessage the exception message to use if the check fails; will be converted to a string using
     *            {@link String#valueOf(Object)}
     * @return the non-null reference that was validated
     * @throws NullPointerException if {@code reference} is null
     */
    public static <T> T checkNotNull( T reference, Object errorMessage )
    {
        if ( reference == null )
        {
            throw new NullPointerException( String.valueOf( errorMessage ) );
        }
        return reference;
    }
}
